@@ -67,7 +67,7 @@ __xonsh__.env['PROMPT_FIELDS']['date_time_tz'] = _field_date_time_tz
 def _screens():
     line = []
     sty = None
-    for l in __xonsh__.subproc_captured_stdout(['screen', '-ls']).splitlines(): 
+    for l in __xonsh__.subproc_captured_stdout(['bash', '-c', 'screen -ls; exit 0']).splitlines():  # bash is to fix https://github.com/xonsh/xonsh/issues/4912 
         if '\t' in l:
             screen_name = l.split('\t')[1].split('.')[1]
             if sty is None:  # lazy load
@@ -156,8 +156,11 @@ def _prompt_bar():
     return f'{_BAR_BG}{_BAR_FG}{lpc}{_BAR_BG}{_BAR_FG}{w}{rpc}'
 
 @events.on_postcommand
-def _(**kwargs):
-    print('')
+def _(cmd, rtn, **kwargs):
+    if rtn != 0 and __xonsh__.env.get('XONTRIB_PROMPT_BAR_SHOW_RETURN', True):
+        printx(f"{{RED}}Return {rtn}{{RESET}}\n")
+    else:
+        print('')
 
 __xonsh__.env['PROMPT_FIELDS']['prompt_bar'] = _prompt_bar
 __xonsh__.env['PROMPT'] = "{prompt_bar}{RESET}\n{WHITE}{prompt_end_xonsh}{RESET} "
